// SettingsDialog.cpp : implementation file
//

#include "stdafx.h"
#include "resource.h"   	// main symbols
#include "systrayplay.h"
#include "SettingsDialog.h"
#include "MainWnd.h"
#include "SeekDialog.h"
#include "MainHelper.h"
#include "TestPropertyPage.h"
#include "Tools/Draw.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CPtrArray listPrefs;

/////////////////////////////////////////////////////////////////////////////
// CSettingsDialog dialog


CSettingsDialog::CSettingsDialog() : CDialog(CSettingsDialog::IDD)
{
	loadSkin.toolTipText = pMainFrame->mySkin.toolTipText;
	toolTipText = pMainFrame->mySkin.toolTipText;
	toolTipText.Replace(_T("\\r\\n"), _T("\r\n"));
	toolTipText.Replace(_T("\\t"), _T("\t"));
}

CSettingsDialog::~CSettingsDialog()
{
	CPropertyPage* myPage;
	if (listPropertyPage.GetSize() != 0)
		do
		{
			myPage = (CPropertyPage *)listPropertyPage[listPropertyPage.GetSize() - 1];
			delete myPage;
			myPage = NULL;
			listPropertyPage.SetSize(listPropertyPage.GetSize() - 1);
		}
		while (listPropertyPage.GetSize() != 0);
	delete m_tooltip;
	SettingsDialog = NULL;
}

IMPLEMENT_MENUXP(CSettingsDialog, CDialog);

BEGIN_MESSAGE_MAP(CSettingsDialog, CDialog)
	ON_WM_CLOSE()
	ON_MENUXP_MESSAGES()
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSettingsDialog message handlers

BOOL CSettingsDialog::DestroyWindow()
{
	m_TabSetting.DestroyWindow();
	return CDialog::DestroyWindow();
}

void CSettingsDialog::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	CMenuXP::SetXPLookNFeel(this, pMainFrame->XPLookNFeel);
	DDX_Control(pDX, IDOK, m_BtnOk);
	DDX_Control(pDX, IDCANCEL, m_BtnCancel);
}

CSettingsDialog* CSettingsDialog::getInstance()
{
	if (SettingsDialog != NULL && SettingsDialog->m_hWnd != NULL)
		SettingsDialog->DestroyWindow();
	if (SettingsDialog != NULL && SettingsDialog->m_hWnd == NULL)
	{
		delete SettingsDialog;
		SettingsDialog = NULL;
	}
	if (SettingsDialog == NULL)
	{
		SettingsDialog = new CSettingsDialog();
		SettingsDialog->Create(CSettingsDialog::IDD);
	}
	else
		SettingsDialog->SetFocus();
	return SettingsDialog;
}

IMPLEMENT_DYNAMIC(CSettingsDialog, CDialog)

BOOL CSettingsDialog::OnInitDialog()
{
	CDialog::OnInitDialog();
	int i = 0;

	m_tooltip = new CPPToolTip();
	m_tooltip->Create(this);

	m_Helper.translateWindowText(this, IDD_SETTINGS);
	m_Helper.translateDlgItemText(this, IDOK);
	m_Helper.translateDlgItemText(this, IDCANCEL);

	m_TabSetting.EnableStackedTabs(FALSE);
	m_TabSetting.AddPage(&m_SettingsDialogGeneral);
	m_TabSetting.AddPage(&m_SettingsDialogHotkeys);
	m_TabSetting.AddPage(&m_SettingsDialogW2File);
	m_TabSetting.AddPage(&m_SettingsDialogMouseClicks);
	m_TabSetting.AddPage(&m_SettingsDialogApparence);
	m_TabSetting.AddPage(&m_SettingsDialogApparenceSkins);
	m_TabSetting.AddPage(&m_SettingsDialogApparenceTooltip);
	m_TabSetting.AddPage(&m_SettingsDialogInput);
	m_TabSetting.AddPage(&m_SettingsDialogOutput);
	m_TabSetting.AddPage(&m_SettingsDialogGen);

	//Cration des pages supplmentaires
	CTestPropertyPage* myPage = NULL;
	for (i = 0; i < listPrefs.GetSize(); i++)
	{
		prefsDlgRec* prefs = (prefsDlgRec*)listPrefs[i];
		try
		{
			myPage = new CTestPropertyPage(prefs, prefs->dlgID);
			listPropertyPage.SetSize(listPropertyPage.GetSize() + 1);
			listPropertyPage[listPropertyPage.GetSize() - 1] = myPage;
			m_TabSetting.AddPage(myPage);
			myPage->InstallHook();
		}
		catch (...)
		{
			listPrefs.RemoveAt(i);
		}
	}   
	m_TabSetting.SetTreeViewMode(TRUE, TRUE);
	m_TabSetting.SetTreeWidth(200);
	m_TabSetting.Create(this, WS_CHILD | WS_VISIBLE | WS_TABSTOP);
	m_TabSetting.ModifyStyleEx(0, WS_EX_CONTROLPARENT);

	CRect rcSheet, rcPage, rectTree;
	GetWindowRect(&rcSheet);
	ScreenToClient(&rcSheet);

	TC_ITEM item;
	CString buf;

	item.mask = TCIF_TEXT;

	m_TabSetting.SetActivePage(0);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogGeneral, IDD_SETTINGS_GENERAL);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(0, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(1);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogHotkeys, IDD_SETTINGS_HOTKEYS);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(1, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(2);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogW2File, IDD_SETTINGS_W2FILE);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(2, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(3);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogMouseClicks, IDD_SETTINGS_MOUSE_CLICKS);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(3, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(4);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogApparence, IDD_SETTINGS_APPARENCE);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(4, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(5);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogApparenceSkins, IDD_SETTINGS_APPARENCE_SKINS);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(5, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(6);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogApparenceTooltip, IDD_SETTINGS_APPARENCE_TOOLTIP);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(6, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(7);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogInput, IDD_SETTINGS_INPUT);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(7, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(8);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogOutput, IDD_SETTINGS_OUTPUT);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(8, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	m_TabSetting.SetActivePage(9);
	buf = m_Helper.translateWindowTextString(&m_SettingsDialogGen, IDD_SETTINGS_GEN);
	item.pszText = (LPTSTR)buf.GetString();
	m_TabSetting.GetTabControl()->SetItem(9, &item);
	m_TabSetting.GetActivePage()->GetClientRect(rcPage);
	if (rcPage.Width() > rcSheet.Width())
		rcSheet.right += (rcPage.Width() - rcSheet.Width());
	if (rcPage.Height() > rcSheet.Height())
		rcSheet.bottom += (rcPage.Height() - rcSheet.Height());

	for (i = 0; i < listPrefs.GetSize(); i++)
	{
		prefsDlgRec* prefs = (prefsDlgRec*)listPrefs[i];
		CString tmp2;
		if (prefs->where == 0)
		{
			buf = m_Helper.translateWindowTextString(&m_SettingsDialogGen, IDD_SETTINGS_GEN);
			tmp2.Format(_T("%s::"), buf);
		}
		buf.Format(_T("%s%s"), tmp2, prefs->name);
		item.pszText = (LPTSTR)buf.GetString();
		m_TabSetting.GetTabControl()->SetItem(10 + i, &item);
		m_TabSetting.GetActivePage()->GetClientRect(rcPage);
		if (rcPage.Width() > rcSheet.Width())
			rcSheet.right += (rcPage.Width() - rcSheet.Width());
		if (rcPage.Height() > rcSheet.Height())
			rcSheet.bottom += (rcPage.Height() - rcSheet.Height());
	}   

	m_TabSetting.RefillPageTree();

	m_TabSetting.SetActivePage(0);
	CRect posOk;
	m_BtnOk.GetClientRect(posOk);
	posOk.right = 70;
	posOk.bottom = 25;
	m_BtnOk.SetWindowPos(NULL, rcSheet.Width() + 40 - 2 * posOk.Width(), rcSheet.bottom - 5, posOk.Width(), posOk.Height(),
						 SWP_NOZORDER | SWP_NOACTIVATE);
	CRect posCancel;
	m_BtnCancel.GetClientRect(posCancel);
	posCancel.right = 70;
	posCancel.bottom = 25;
	m_BtnCancel.SetWindowPos(NULL, rcSheet.Width() - 20, rcSheet.bottom - 5, posCancel.Width(), posCancel.Height(), SWP_NOZORDER | SWP_NOACTIVATE);
	SetWindowPos(NULL, -1, -1, rcSheet.Width() + 65, rcSheet.Height() + 5 + posOk.Height(), SWP_SHOWWINDOW | SWP_NOMOVE);
	m_TabSetting.GetTabControl()->ShowWindow(SW_HIDE);
	SetIcon(pMainFrame->StpIcon, TRUE);
	SetIcon(pMainFrame->StpIconSm, FALSE);

	UpdateData(false);

	return TRUE;  // return TRUE unless you set the focus to a control
	// EXCEPTION: OCX Property Pages should return FALSE
}

void CSettingsDialog::SetActivePage(int index)
{
	/*
	** Winamp Pro   		20
	** General Preferences  0
	** File Types   		1
	** Playlist 			23
	** Titles   			21
	** Video				24
	** Skins				40
	** Classic Skins		22
	** Plugins  			30
	** Input				31
	** Output   			32
	** Visualisation		33
	** DSP/Effect   		34
	** General Purpose  	35
	*/
	switch (index)
	{
	case 20:
	case 0:
	case 1:
	case 23:
	case 21:
	case 24:
	case 33:
	case 34:
		m_TabSetting.SetActivePage(0);
		break;
	case 40:
	case 22:
		m_TabSetting.SetActivePage(4);
		break;
	case 30:
	case 31:
		m_TabSetting.SetActivePage(7);
		break;
	case 32:
		m_TabSetting.SetActivePage(8);
		break;
	case 35:
		m_TabSetting.SetActivePage(9);
		break;
	default:
		if (index >= 60)
			for (int i = 0; i < listPropertyPage.GetSize(); i++)
			{
				CTestPropertyPage* page = (CTestPropertyPage*)listPropertyPage[i];
				if (page->PageDataBackup->dlgID == index)
				{
					m_TabSetting.SetActivePage(10 + i);
					break;
				}
			}
	}
}
void CSettingsDialog::SetActivePage(prefsDlgRec* iPrefs)
{
	for (int i = 0; i < listPropertyPage.GetSize(); i++)
	{
		CTestPropertyPage* page = (CTestPropertyPage*)listPropertyPage[i];
		if (page->PageDataBackup->proc == iPrefs->proc)
		{
			m_TabSetting.SetActivePage(10 + i);
			break;
		}
	}
}

void CSettingsDialog::OnOK()
{
	UpdateData(TRUE);
	m_TabSetting.PressButton(PSBTN_APPLYNOW);
	CDialog::OnOK();
	if (pMainFrame->needToRestart)
	{
		ShellExecute(NULL, _T("open"), pMainFrame->exename, _T("-restart"), NULL, SW_SHOWNORMAL);
		MessageBox(m_Helper.MyLoadString(IDS_UPDATEOK), _T("STP"), MB_ICONINFORMATION | MB_OK);
		pMainFrame->OnPopupMenuExit();
	}
	if (SettingsDialog != NULL && SettingsDialog->m_hWnd != NULL)
		SettingsDialog->DestroyWindow();
	if (SettingsDialog != NULL)
		delete SettingsDialog;
	SettingsDialog = NULL;
}

void CSettingsDialog::OnCancel()
{
	m_TabSetting.PressButton(PSBTN_CANCEL);
	CDialog::OnCancel();
	if (SettingsDialog != NULL && SettingsDialog->m_hWnd != NULL)
		SettingsDialog->DestroyWindow();
	if (SettingsDialog != NULL)
		delete SettingsDialog;
	SettingsDialog = NULL;
}

void CSettingsDialog::DisplaySkin(CWnd* pSkinSampleWnd, int frg, int forceText)
{
	if (pSkinSampleWnd)
	{
		CDC* pDC = pSkinSampleWnd->GetDC();
		HDC hDC = CreateCompatibleDC(::GetWindowDC(pSkinSampleWnd->m_hWnd));
		CRect rect;
		pSkinSampleWnd->GetClientRect(&rect);

		int oWidth = 90;
		int oHeight = 90;
		SelectObject(hDC, loadSkin.Buttons);

		int imgWidth = (oWidth* rect.Height() < oHeight* rect.Width()) ? oWidth* rect.Height() / oHeight : oWidth;
		int imgHeight = (oWidth* rect.Height() < oHeight* rect.Width()) ? oHeight* imgWidth / oWidth : oHeight;

		HDC hdc1 = CreateCompatibleDC(hDC);
		HBITMAP bm1 = CreateCompatibleBitmap(hDC, imgWidth, imgHeight);
		SelectObject(hdc1, bm1);
		if ((SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(1) == 1 && forceText == -1) || forceText == 0)
		{
			DisplayImage(hDC, hdc1, bm1, rect);
		}
		else
		{
			DisplayText(hDC, hdc1, bm1, rect, -1, forceText);
		}
		if (frg != -1)
		{
			SelectObject(hDC, loadSkin.ButtonsDn);
			HDC hdc2 = CreateCompatibleDC(hDC);
			HBITMAP bm2 = CreateCompatibleBitmap(hDC, imgWidth, imgHeight);
			SelectObject(hdc2, bm2);
			if ((SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(1) == 1 && forceText == -1) || forceText == 0)
			{
				DisplayImage(hDC, hdc2, bm2, rect, frg);
			}
			else
			{
				DisplayText(hDC, hdc2, bm2, rect, frg, forceText);
			}
			StretchBlt(hdc1, rect.left, rect.top + frg * rect.Height() / 5 + 1, rect.Width(), rect.Height() / 5, hdc2, 0, frg * imgHeight / 5 + 1,
					   imgWidth, imgHeight / 5 + 1, SRCCOPY);
			DeleteDC(hdc2);
			DeleteObject(bm2);
		}

		CPen pen(PS_SOLID, 1, RGB(0, 0, 0));

		rect.bottom--;
		rect.right--;
		CDC::FromHandle(hdc1)->SelectObject(pen);
		CDC::FromHandle(hdc1)->MoveTo(rect.TopLeft());
		CDC::FromHandle(hdc1)->LineTo(CPoint(rect.right, rect.top));
		CDC::FromHandle(hdc1)->LineTo(rect.BottomRight());
		CDC::FromHandle(hdc1)->LineTo(CPoint(rect.left, rect.bottom));
		CDC::FromHandle(hdc1)->LineTo(rect.TopLeft());
		StretchBlt(pDC->m_hDC, rect.left, rect.top, rect.Width(), rect.Height(), hdc1, 0, 0, imgWidth, imgHeight, SRCCOPY);

		DeleteDC(hdc1);
		DeleteObject(bm1);
		SelectObject(hDC, loadSkin.Buttons);

		DeleteDC(hDC);
	}
}
void CSettingsDialog::DisplayText(HDC hdc, HDC hdc5, HBITMAP bm5, CRect rect, int frg, int forceText)
{
	CString buf;
	CRect tmp;

	CFontDC font(hdc, DEFAULT_GUI_FONT);
	CFontDC font5(hdc5, DEFAULT_GUI_FONT);
	COLORREF cColor = SetBkColor(hdc, RGB(255, 0, 255));

	COLORREF crHighLight = ::GetSysColor(COLOR_HIGHLIGHT);
	CPenDC pen(hdc5, crHighLight);
	CBrushDC brush(hdc5, frg == -1 ? HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +73, 0) : HLS_TRANSFORM(crHighLight, +70, -57));
	BOOL bGradient = SettingsDialog->m_SettingsDialogApparence.showGradient;
	BOOL bGradientSel = SettingsDialog->m_SettingsDialogApparence.showGradientSel;

	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 && forceText != 1)
	{
		CRect rc(rect);
		rc.right = rc.left + 16 + 8;
		CDC::FromHandle(hdc5)->FillSolidRect(rc, HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +20, 0));
		rc.left = rc.right;
		rc.right = rect.right;
		CDC::FromHandle(hdc5)->FillSolidRect(rc, HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +75, 0));
		if (frg != -1)
		{
			SetBkColor(hdc, cColor);
			CRect grad;
			grad = rect;
			if (bGradient && bGradientSel)
			{
				SeekDialog->DrawGradient(CDC::FromHandle(hdc5), SettingsDialog->m_SettingsDialogApparence.startColor.GetColour(),
										 SettingsDialog->m_SettingsDialogApparence.endColor.GetColour(), &grad);
				CBrushDC brush(hdc5, CLR_NONE);
				CDC::FromHandle(hdc5)->Rectangle(rect);
			}
			else
				CDC::FromHandle(hdc5)->Rectangle(rect);
		}
		else
		{
			SetBkColor(hdc, cColor);
			CRect grad;
			grad = rect;
			grad.right = grad.left + 30;
			if (bGradient)
			{
				SeekDialog->DrawGradient(CDC::FromHandle(hdc5), SettingsDialog->m_SettingsDialogApparence.startColor.GetColour(),
										 SettingsDialog->m_SettingsDialogApparence.endColor.GetColour(), &grad);
				CBrushDC brush(hdc5, CLR_NONE);
				CDC::FromHandle(hdc5)->Rectangle(rect);
				grad = rect;
				grad.left += 30;
				CDC::FromHandle(hdc5)->FillSolidRect(grad, SettingsDialog->m_SettingsDialogApparence.endColor.GetColour());
			}
		}
	}
	else
	{
		if (frg != -1)
		{
			CDC::FromHandle(hdc5)->SetTextColor(::GetSysColor(COLOR_HIGHLIGHTTEXT));
			SetBkColor(hdc5, cColor);
			CDC::FromHandle(hdc5)->FillSolidRect(0, 0, rect.Width(), rect.Height(), GetSysColor(COLOR_HIGHLIGHT));
		}
		else
		{
			CDC::FromHandle(hdc5)->SetTextColor(::GetSysColor(COLOR_WINDOWTEXT));
			SetBkColor(hdc5, cColor);
			CDC::FromHandle(hdc5)->FillSolidRect(0, 0, rect.Width(), rect.Height(),
												 (forceText == 1) ? GetSysColor(COLOR_MENU) : GetSysColor(COLOR_MENU));
		}
	}

	SetBkMode(hdc5, TRANSPARENT);

	tmp = rect;
	if (frg != -1 && SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1)
	{
		CPen pen(PS_SOLID, 1, ::GetSysColor(COLOR_HIGHLIGHT));

		tmp.left += 2;
		tmp.right -= 3;
		tmp.top = rect.top + frg * rect.Height() / 5 + 1;
		tmp.bottom = rect.top + (1 + frg) * rect.Height() / 5;

		CDC::FromHandle(hdc5)->SelectObject(pen);
		CDC::FromHandle(hdc5)->MoveTo(CPoint(tmp.right, tmp.top));
		CDC::FromHandle(hdc5)->LineTo(tmp.BottomRight());
		CDC::FromHandle(hdc5)->LineTo(CPoint(tmp.left, tmp.bottom));
		CDC::FromHandle(hdc5)->LineTo(tmp.TopLeft());
		CDC::FromHandle(hdc5)->LineTo(CPoint(tmp.right, tmp.top));
		tmp.left -= 2;
		tmp.right += 3;
	}
	tmp.left += 32;

	buf = m_Helper.MyLoadString(ID_POPUPMENU_PLAY);
	tmp.top = rect.top;
	tmp.bottom = rect.bottom - 4 * rect.Height() / 5;
	CDC::FromHandle(hdc5)->DrawText(buf, tmp, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_VCENTER);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 || forceText == 1)
	{
		if (frg == 0)
			CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 5 : 4), tmp.top + ((frg != -1) ? 6 : 4)), CSize(16, 16), loadSkin.PlayIcon,
											 DSS_MONO,
											 CBrush((frg != -1) ? HLS_TRANSFORM(::GetSysColor(COLOR_HIGHLIGHT), +50, -66) :
													HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), -27, 0)));
		CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 3 : 4), tmp.top + ((frg != -1) ? 3 : 4)), CSize(16, 16), loadSkin.PlayIcon,
										 DSS_NORMAL, (HBRUSH)NULL);
	}

	buf = m_Helper.MyLoadString(ID_POPUPMENU_PAUSE);
	tmp.top = rect.top + rect.Height() / 5;
	tmp.bottom = rect.bottom - 3 * rect.Height() / 5;
	CDC::FromHandle(hdc5)->DrawText(buf, tmp, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_VCENTER);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 || forceText == 1)
	{
		if (frg == 1)
			CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 5 : 4), tmp.top + ((frg != -1) ? 6 : 4)), CSize(16, 16), loadSkin.PauseIcon,
											 DSS_MONO,
											 CBrush((frg != -1) ? HLS_TRANSFORM(::GetSysColor(COLOR_HIGHLIGHT), +50, -66) :
													HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), -27, 0)));
		CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 3 : 4), tmp.top + ((frg != -1) ? 3 : 4)), CSize(16, 16), loadSkin.PauseIcon,
										 DSS_NORMAL, (HBRUSH)NULL);
	}
	buf = m_Helper.MyLoadString(ID_POPUPMENU_STOP);
	tmp.top = rect.top + 2 * rect.Height() / 5;
	tmp.bottom = rect.bottom - 2 * rect.Height() / 5;
	CDC::FromHandle(hdc5)->DrawText(buf, tmp, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_VCENTER);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 || forceText == 1)
	{
		if (frg == 2)
			CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 5 : 4), tmp.top + ((frg != -1) ? 6 : 4)), CSize(16, 16), loadSkin.StopIcon,
											 DSS_MONO,
											 CBrush((frg != -1) ? HLS_TRANSFORM(::GetSysColor(COLOR_HIGHLIGHT), +50, -66) :
													HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), -27, 0)));
		CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 3 : 4), tmp.top + ((frg != -1) ? 3 : 4)), CSize(16, 16), loadSkin.StopIcon,
										 DSS_NORMAL, (HBRUSH)NULL);
	}

	buf = m_Helper.MyLoadString(ID_POPUPMENU_PREVIOUS);
	tmp.top = rect.top + 3 * rect.Height() / 5;
	tmp.bottom = rect.bottom - rect.Height() / 5;
	CDC::FromHandle(hdc5)->DrawText(buf, tmp, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_VCENTER);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 || forceText == 1)
	{
		if (frg == 3)
			CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 5 : 4), tmp.top + ((frg != -1) ? 6 : 4)), CSize(16, 16), loadSkin.PrevIcon,
											 DSS_MONO,
											 CBrush((frg != -1) ? HLS_TRANSFORM(::GetSysColor(COLOR_HIGHLIGHT), +50, -66) :
													HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), -27, 0)));
		CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 3 : 4), tmp.top + ((frg != -1) ? 3 : 4)), CSize(16, 16), loadSkin.PrevIcon,
										 DSS_NORMAL, (HBRUSH)NULL);
	}

	buf = m_Helper.MyLoadString(ID_POPUPMENU_NEXT);
	tmp.top = rect.top + 4 * rect.Height() / 5;
	tmp.bottom = rect.bottom;
	CDC::FromHandle(hdc5)->DrawText(buf, tmp, DT_LEFT | DT_SINGLELINE | DT_NOPREFIX | DT_VCENTER);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1 || forceText == 1)
	{
		if (frg == 4)
			CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 5 : 4), tmp.top + ((frg != -1) ? 6 : 4)), CSize(16, 16), loadSkin.NextIcon,
											 DSS_MONO,
											 CBrush((frg != -1) ? HLS_TRANSFORM(::GetSysColor(COLOR_HIGHLIGHT), +50, -66) :
													HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), -27, 0)));
		CDC::FromHandle(hdc5)->DrawState(CPoint(1 + ((frg != -1) ? 3 : 4), tmp.top + ((frg != -1) ? 3 : 4)), CSize(16, 16), loadSkin.NextIcon,
										 DSS_NORMAL, (HBRUSH)NULL);
	}

	ReleaseDC(CDC::FromHandle(hdc5));
}

void CSettingsDialog::DisplayImage(HDC hdc, HDC hdc5, HBITMAP bm5, CRect rect, int frg)
{
	int oWidth = 90;
	int oHeight = 90;
	int imgWidth = (oWidth* rect.Height() < oHeight* rect.Width()) ? oWidth* rect.Height() / oHeight : oWidth;
	int imgHeight = (oWidth* rect.Height() < oHeight* rect.Width()) ? oHeight* imgWidth / oWidth : oHeight;

	HDC hdc1 = CreateCompatibleDC(hdc);
	HDC hdc2 = CreateCompatibleDC(hdc);
	HDC hdc3 = CreateCompatibleDC(hdc);
	HDC hdc4 = CreateCompatibleDC(hdc);
	//Masque binaire
	HBITMAP bm1 = CreateBitmap(imgWidth, imgHeight, 1, 1, NULL);
	HBITMAP bm2 = CreateBitmap(imgWidth, imgHeight, 1, 1, NULL);
	HBITMAP bm3 = CreateCompatibleBitmap(hdc, imgWidth, imgHeight);
	HBITMAP bm4 = CreateCompatibleBitmap(hdc, imgWidth, imgHeight);
	SelectObject(hdc1, bm1);
	SelectObject(hdc2, bm2);
	SelectObject(hdc3, bm3);
	SelectObject(hdc4, bm4);

	COLORREF cColor = SetBkColor(hdc, RGB(255, 0, 255));
	COLORREF crHighLight = ::GetSysColor(COLOR_HIGHLIGHT);
	CPenDC pen(hdc5, crHighLight);
	CBrushDC brush(hdc5, frg == -1 ? HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +73, 0) : HLS_TRANSFORM(crHighLight, +70, -57));
	BOOL bGradient = SettingsDialog->m_SettingsDialogApparence.showGradient;
	BOOL bGradientSel = SettingsDialog->m_SettingsDialogApparence.showGradientSel;

	//Image Original
	StretchBlt(hdc1, 0, 0, imgWidth, imgHeight, hdc, 0, 0, oWidth, oHeight, SRCCOPY);
	//Image invers
	StretchBlt(hdc2, 0, 0, imgWidth, imgHeight, hdc, 0, 0, oWidth, oHeight, NOTSRCCOPY);
	if (SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1)
	{
		CRect rc(rect);
		rc.right = rc.left + 16 + 8;
		CDC::FromHandle(hdc5)->FillSolidRect(rc, HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +20, 0));
		rc.left = rc.right;
		rc.right = rect.right;
		CDC::FromHandle(hdc5)->FillSolidRect(rc, HLS_TRANSFORM(::GetSysColor(COLOR_3DFACE), +75, 0));
		if (frg != -1)
		{
			SetBkColor(hdc, cColor);
			CRect grad;
			grad = rect;
			if (bGradient && bGradientSel)
			{
				SeekDialog->DrawGradient(CDC::FromHandle(hdc5), SettingsDialog->m_SettingsDialogApparence.startColor.GetColour(),
										 SettingsDialog->m_SettingsDialogApparence.endColor.GetColour(), &grad);
				CBrushDC brush(hdc5, CLR_NONE);
				CDC::FromHandle(hdc5)->Rectangle(rect);
			}
			else
				CDC::FromHandle(hdc5)->Rectangle(rect);
		}
		else
		{
			SetBkColor(hdc, cColor);
			CRect grad;
			grad = rect;
			grad.right = grad.left + 30;
			if (bGradient)
			{
				SeekDialog->DrawGradient(CDC::FromHandle(hdc5), SettingsDialog->m_SettingsDialogApparence.startColor.GetColour(),
										 SettingsDialog->m_SettingsDialogApparence.endColor.GetColour(), &grad);
				grad = rect;
				grad.left += 30;
				CDC::FromHandle(hdc5)->FillSolidRect(grad, SettingsDialog->m_SettingsDialogApparence.endColor.GetColour());
			}
		}
	}
	else
	{
		if (frg != -1)
		{
			SetBkColor(hdc1, cColor);
			CDC::FromHandle(hdc5)->FillSolidRect(0, 0, rect.Width(), imgHeight, GetSysColor(COLOR_HIGHLIGHT));
		}
		else
		{
			SetBkColor(hdc1, cColor);
			CDC::FromHandle(hdc5)->FillSolidRect(0, 0, rect.Width(), imgHeight, GetSysColor(COLOR_MENU));
		}
	}
	StretchBlt(hdc3, 0, 0, imgWidth, imgHeight, hdc5, (rect.Width() - imgWidth) / 2, 0, imgWidth, imgHeight, SRCCOPY);
	StretchBlt(hdc4, 0, 0, imgWidth, imgHeight, hdc, 0, 0, oWidth, oHeight, SRCCOPY);
	//Fond Orignal
	//Et entre Image invers et fond
	BitBlt(hdc3, 0, 0, imgWidth, imgHeight, hdc1, 0, 0, SRCAND);
	BitBlt(hdc4, 0, 0, imgWidth, imgHeight, hdc2, 0, 0, SRCAND);
	//Ou entre les 2 images obtenu
	BitBlt(hdc4, 0, 0, imgWidth, imgHeight, hdc3, 0, 0, SRCPAINT);
	BitBlt(hdc5, 0, 0, imgWidth, imgHeight, hdc4, 0, 0, SRCCOPY);

	CRect tmp = rect;
	if (frg != -1 && SettingsDialog->m_SettingsDialogGeneral.m_l_options.GetCheck(2) == 1)
	{
		CPen pen(PS_SOLID, 1, ::GetSysColor(COLOR_HIGHLIGHT));

		tmp.left += 2;
		tmp.right -= 3;
		tmp.top = rect.top + frg * rect.Height() / 5 + 1;
		tmp.bottom = rect.top + (1 + frg) * rect.Height() / 5;

		CDC::FromHandle(hdc5)->SelectObject(pen);
		CDC::FromHandle(hdc5)->MoveTo(CPoint(tmp.right, tmp.top));
		CDC::FromHandle(hdc5)->LineTo(tmp.BottomRight());
		CDC::FromHandle(hdc5)->LineTo(CPoint(tmp.left, tmp.bottom));
		CDC::FromHandle(hdc5)->LineTo(tmp.TopLeft());
		CDC::FromHandle(hdc5)->LineTo(CPoint(tmp.right, tmp.top));
		tmp.left -= 2;
		tmp.right += 3;
	}

	DeleteDC(hdc1);
	DeleteObject(bm1);
	DeleteDC(hdc2);
	DeleteObject(bm2);
	DeleteDC(hdc3);
	DeleteObject(bm3);
	DeleteDC(hdc4);
	DeleteObject(bm4);
}

